Blavet: Blavet French river dataset

BlavetR Documentation

Blavet French river dataset

Description

'Blavet' is a dataset for the Blavet River on the Brittany peninsula in France and two neighbouring rivers (Claie and Coët-Organ). It contains all the inputs required to test the package and predict discharge at the outlets of six catchments:

  • J5613010: Evel at Guénin (316 km²)

  • J5618310: Fremeur et Guénin (15.1 km²)

  • J5618320: Fremeur et Pluméliau (5.88 km²)

  • J5704810: Coët-Organ at Quistinic (47.7 km²)

  • J8433020: Claie at Saint-Jean-Brévelay (135 km²)

  • AgrHys: Coët-Dan at Naizin (4.9 km²)

Hourly discharge observations for the six catchments are provided for one hydrological year, from 2013-10-01 to 2014-10-01. They were extracted from the French HYDRO database (http://www.hydro.eaufrance.fr), except for the Coët-Dan observations, which were provided by the AgrHys Environmental Research Observatory \insertCiteFovet2018transfR, managed by INRAE (https://www6.inrae.fr/ore_agrhys_eng). Catchment delineations and the corresponding hydraulic-length maps were extracted from a digital elevation model with a resolution of 100 m.

Format

'Blavet' is a list of three objects:

  • hl: A list of stars objects containing the six raster maps of hydraulic length.

  • obs: A stars object with two dimensions (time and space, with catchment delineations as spatial support) and one attribute (discharge observations).

  • network: An sf object representing the [French TOPAGE river network](https://bdtopage.eaufrance.fr/). It can be downloaded using the "Sandre - Eau France" Web Feature Service (WFS), as shown in the example below.

http://www.hydro.eaufrance.fr

https://www6.inrae.fr/ore_agrhys_eng

http://bdtopage.eaufrance.fr

References

\insertRef

Fovet2018transfR

Examples

## Not run: 
# Working directory
wd <- tempdir(check = TRUE)
# Define a bbox that will encompass the catchments of the study area
blavet_bbox <- st_bbox(c(xmin = -3.3, xmax = -2.7, ymax = 48.11, ymin = 47.77),
                           crs = st_crs(4326))
# Download a French Topage river network within the bbox using the "Sandre - Eau France" WFS
download.file(url = paste0("https://services.sandre.eaufrance.fr/geo/topage2019",
                     "?request=GetFeature&service=WFS&version=2.0.0",
                     "&typeName=CoursEau_FXX_Topage2019",
                     "&outputFormat=application/json;
                     paste0(blavet_bbox[c("ymin","xmin","ymax","xmax")],
                            collapse=",")),
              destfile = file.path(wd,"CoursEau_FXX_Topage2019.geojson"))
CoursEau_Topage2019 <- st_read(dsn = file.path(wd,"CoursEau_FXX_Topage2019.geojson"),
                               drivers = "GeoJSON", stringsAsFactors = FALSE, quiet = FALSE,
                               query = "SELECT gid FROM CoursEau_FXX_Topage2019")

## End(Not run)

transfR documentation built on July 24, 2026, 5:06 p.m.