| as_transfr | R Documentation |
Create a transfR object or add new attributes to a transfR object.
as_transfr(
object,
st,
uc,
lagtime,
surface,
delineation,
outlet,
centroid,
uh,
hl
)
object |
object of class |
st |
spatio-temporal array of class |
uc |
vector of the streamflow velocities of the catchments. If no unit is provided, |
lagtime |
vector of the lag times of the catchments. If no unit is provided, |
surface |
vector of the surfaces of the catchments. If no unit is provided, |
delineation |
spatial layer of the boundary of the catchments of class |
outlet |
spatial layer of the outlets of the catchments of class |
centroid |
spatial layer of the centroids of the catchments of class |
uh |
list of the unit hydrographs of the catchments. |
hl |
list of hydraulic length objects, one per catchment. Each element must be a |
This function creates an object of class transfR or adds new attributes to an existing transfR object.
It can be used to gather and organise most of the inputs and outputs of the other functions,
like streamflow velocities, unit hydrographs, a priori estimates of net rainfall, inversions and simulations for every catchment.
This function can be used to organise the two user inputs required for a conventional use of the package, namely st
and hl. The hydraulic lengths are defined as the flow path length from each pixel to the outlet within
the river network \insertCiteCudennec2004,Aouissi2013transfR. Catchment delineations and hydraulic lengths
need to be prepared beforehand by the user. This package does not provide functions to create them.
However, several GIS software packages can extract them from a digital elevation model,
such as GRASS toolkits \insertCiteJasiewicz2011transfR,
Whitebox GAT (\insertCite@see @Lindsay2016;textualtransfR or WhiteboxTools),
TauDEM (D. Tarboton, Utah State University)
or online services (\insertCite@see @Squividant2015;textualtransfR for catchment delineation in the Brittany French region).
An object of class transfR.
Aouissi2013transfR
\insertRefCudennec2004transfR
\insertRefJasiewicz2011transfR
\insertRefLindsay2016transfR
\insertRefSquividant2015transfR
data(Oudon)
object <- as_transfr(st = Oudon$obs, hl = Oudon$hl)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.