transfR: Transfer of Hydrograph from Gauged to Ungauged Catchments

transfR-packageR Documentation

Transfer of Hydrograph from Gauged to Ungauged Catchments

Description

This R package proposes a geomorphology-based hydrological modelling approach to transfer streamflow measurements from gauged catchments to ungauged catchments, i.e. where there is no station monitoring the streamflow. It follows a runoff-runoff approach, i.e. it directly combines the observed streamflow series available at monitoring stations to estimate streamflow elsewhere in the surrounding rivers without the need to implement a full rainfall-runoff model. The package itself and the theoretical aspects of the approach are presented in detail and discussed by de Lavenne et al. (2023).

## — Short description of the modelling approach

The hydrological modelling is based on a description of the hydro-geomorphometry of the river network, which can be easily observed for any given outlet. An inversion of this model for a gauged catchment allows the observed streamflow series to be deconvoluted in order to estimate an almost scale-independent signal, namely the net rainfall \insertCiteBoudhraa2018transfR. Transferring this estimate of the net rainfall series to a targeted ungauged catchment then makes it possible to simulate the streamflow there. The use of streamflow observations from several gauged catchments in the neighbourhood increases the robustness of the simulation \insertCitedeLavenne2016transfR. The methodology was first implemented on a few catchments in semiarid Tunisia at the event time scale \insertCiteBoudhraa2009transfR, then in dense configurations of neighbouring and nested catchments in France, which mainly have a temperate oceanic climate \insertCitedeLavenne2015,deLavenne2016,deLavenne2019transfR, and in snow-influenced Québec, Canada \insertCiteEcrepont2019transfR.

## — Functions and objects

To implement the method, it is advised to explore the following functions in this order:

  • as_transfr creates a “transfR” database from a “stars” object and a morphometric description of the catchments (hydraulic lengths)

  • velocity estimates the main model parameter, i.e. the streamflow velocity, from different regionalisation strategies

  • uh estimates a simple linear model, i.e. the unit hydrograph, based on the analysis of catchment geomorphology and streamflow velocity

  • rapriori provides an a priori estimate of net rainfall, as needed for model inversion

  • inversion estimates net rainfall by inverse modelling

  • hdist computes hydrological distances between catchments, such as the rescaled Ghosh distances

  • mixr estimates the net rainfall of one catchment by averaging the net rainfall of neighbouring gauged catchments, weighted according to hydrological distances

  • convolution computes the convolution of the net rainfall by the unit hydrograph to estimate streamflow

## — How to get started

This package comes with two datasets (Blavet and Oudon) that contain all the necessary inputs to test the package and perform discharge prediction. Users are advised to check the 'Get started with transfR' vignette (vignette("V01_get_started", package = "transfR")) that provides a complete implementation of the method with the Oudon dataset. Two additional vignettes are proposed to help the preparation of input data: a spatiotemporal array of observed discharge (vignette("V02_inputs_preparation_stars", package = "transfR")) and a morphometric description of the catchments (vignette("V03_inputs_preparation_whitebox", package = "transfR")). In addition, each function comes with different examples.

A detailed description of the modelling approach and the package has been published by de Lavenne et al. (2023): the theoretical aspects of each modelling step are described in more detail, arguments justifying the default values used in the functions are presented, and limitations of the approach are discussed for a consistent implementation of the approach.

For the French region of Brittany, a web service using this package was developed to facilitate the implementation of the method without the need for the user to have programming skills in R or to collect the necessary input data \insertCiteDallery2020transfR.

References

\insertRef

Boudhraa2009transfR

\insertRef

Boudhraa2018transfR

\insertRef

Ecrepont2019transfR

\insertRef

Dallery2020transfR

\insertRef

deLavenne2015transfR

\insertRef

deLavenne2016transfR

\insertRef

deLavenne2019transfR

\insertRef

deLavenne2023transfR


transfR documentation built on July 24, 2026, 5:06 p.m.