| uh | R Documentation |
Estimate the unit hydrograph from a sample of hydraulic lengths and a streamflow velocity.
uh(hl, ...)
## Default S3 method:
uh(hl, uc, deltat, ...)
## S3 method for class 'units'
uh(hl, uc, deltat, ...)
## S3 method for class 'stars'
uh(hl, ...)
## S3 method for class 'transfR'
uh(hl, verbose = TRUE, ...)
hl |
hydraulic length of class |
... |
further arguments passed to or from other methods |
uc |
streamflow velocity. If no unit is provided, |
deltat |
time step of the time series. If no unit is provided, |
verbose |
logical indicating if information messages should be written to the console |
The function estimates the unit hydrograph from geomorphometric information.
A travel time to the outlet is estimated by assuming an average streamflow velocity (uc)
within the river network and by applying uc to the sample of hydraulic lengths (hl).
The unit hydrograph is the probability distribution of this travel time to the outlet
given at each time step (deltat).
A data frame with vectors of class units or, if hl is a transfR object,
the hl object with the "uh" attribute added.
data(Oudon)
uh1 <- uh(hl=Oudon$hl[[1]], uc=units::set_units(0.5,"m/s"),
deltat=units::set_units(1,"h"))
plot(units::set_units(uh1$max_time,"h"), cumsum(uh1$prob), type = "b",
xlab = "Travel~time", ylab = "Probability~of~non-exceedance")
object <- as_transfr(st = Oudon$obs, hl = Oudon$hl)
object <- velocity(object)
object <- uh(object)
plot(object, i = 1, attribute = c("uh"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.