Create a transfR object or add new attributes to a transfR object.
as_transfr(
object,
st,
uc,
lagtime,
surface,
delineation,
outlet,
centroid,
uh,
hl
)An object of class transfR.
object of class transfR
spatio-temporal arrays of class stars. Observed discharge must be described by the column name 'Qobs'.
Time should be the first dimension, space the second dimension. If no unit is provided, Qobs is assumed to be in [m3/s]
and RnInv is assumed to be in [mm/h] (or [mm/d] at daily time step).
vector of the streamflow velocities of the catchments. If no unit is provided, uc is assumed to be in [m/s].
vector of the lag times of the catchments. If no unit is provided, lagtime is assumed to be in [h].
vector of the surfaces of the catchments. If no unit is provided, surface is assumed to be in [km2].
spatial layer of the boundary of the catchments of class sfc_POLYGON.
spatial layer of the outlets of the catchments of class sfc_POINT.
spatial layer of the centroids of the catchments of class sfc_POINT.
list of the unit hydrographs of the catchments.
hydraulic length of class stars, matrix or vector. If no unit is provided, hl
is assumed to be in [m]. See details below.
This function creates an object of class transfR or increment an existing transfR object
with new attributes. It can be used to gather and organize most of the inputs and outputs of the other functions
like streamflow velocities, unit hydrograph, a priori on net rainfall, inversions and simulations of every catchments.
This function can be used to organise the two user inputs required for a conventional use of the package, namely st
and hl. The hydraulic lengths are defined as the flow path length from each pixel to the outlet within
the river network Cudennec2004,Aouissi2013transfR. Catchment delineations and hydraulic lengths
need to be prepared beforehand by the user. This package does not provide functions to create them.
However, several GIS software offer possibilities to extract them from a digital elevation model
such as GRASS toolkits Jasiewicz2011transfR,
Whitebox GAT (@see @Lindsay2016;textualtransfR or WhiteboxTools),
TauDEM (D. Tarboton, Utah State University)
or online services (@see @Squividant2015;textualtransfR for catchment delineation in the Brittany French region).
Aouissi2013transfR
Cudennec2004transfR
Jasiewicz2011transfR
Lindsay2016transfR
Squividant2015transfR
data(Oudon)
object <- as_transfr(st = Oudon$obs, hl = Oudon$hl)
Run the code above in your browser using DataLab