| rapriori | R Documentation |
A priori estimate of net rainfall as required for the inversion.
rapriori(Qobs, ...)
## Default S3 method:
rapriori(Qobs, area, lagtime, deltat, ...)
## S3 method for class 'units'
rapriori(Qobs, area, lagtime, deltat, ...)
## S3 method for class 'transfR'
rapriori(Qobs, verbose = TRUE, ...)
Qobs |
vector of discharge values or object of class |
... |
further arguments passed to or from other methods |
area |
drainage area of the catchment. If no unit is provided, |
lagtime |
lag time value of the catchment. If no unit is provided, |
deltat |
time step of the time series. If no unit is provided, |
verbose |
logical indicating if information messages should be written to the console |
The function estimates an a priori value for net rainfall from Qobs. It converts Qobs to specific
discharge and removes the delay caused by transfer time in the river network (given by lagtime
and which can be estimated with lagtime). If an object of class transfR is provided,
area is estimated from its st attribute. Results are stored as a new space-time attribute,
called "RnAp", in the transfR object.
An object of the same class as Qobs. If Qobs is a transfR object,
it is returned with the "RnAp" attribute added.
data(Oudon)
icatch <- 1
Qobs <- Oudon$obs[["Qobs"]][,icatch]
Qspec <- units::set_units(Qobs/st_area(st_geometry(Oudon$obs)[icatch]), "mm/h")
deltat <- units::set_units(1,"h")
uc <- velocity(hl = Oudon$hl[[icatch]])
uh <- uh(hl = Oudon$hl[[icatch]], uc = uc, deltat = deltat)$prob
RnAp <- rapriori(Qobs = Qspec, lagtime = lagtime(hl = Oudon$hl[[icatch]], uc = uc),
deltat = deltat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.